Class AudioCodec::AudioFileStream — sudio documentation

# Class AudioCodec::AudioFileStream

- Defined in File codec.hpp

## Nested Relationships

This class is a nested type of Class AudioCodec.

## Class Documentation

class AudioFileStream

  Public Functions

  AudioFileStream(const std::string &filename, ma_format outputFormat = ma_format_s16, uint32_t nchannels = 2, uint32_t sampleRate = 44100, uint64_t framesToRead = 1024, ma_dither_mode dither = ma_dither_mode_none, uint64_t seekFrame = 0)
  ~AudioFileStream()
  std::vector<uint8_t> readFrames(uint64_t framesToRead = 0)